DESCRIPTION
A wrapper needed to authenticate to iflychat.com.
Setup
You'll need to go here https://iflychat.com/iflyapi/index and register for an API Key. You'll specify that using api_key passed to the constructor.
You'll need to copy the public folder from this distribution onto your web server somewhere. You'll specify where that is using the static_asset_base_uri passed tot he constructor.
You'll need to build 2 things into your web server:
- Inline HTML
-
You'll need to inline the result of
render_htmlinto any web page where you want the chat to appear. - AJAX Method
-
You'll need to set up an ajax method in your app that returns the result of
render_ajax. You'll pass the URL where that can be found into the constructor usingajax_uri.
And finally you need to call update_settings to tell the iFly servers what your settings are.